# `testpypibkonon` - My Simple Project
* Opt1
* Opt2
* Opt3

## Install
```python
pip install testpypibkonon
```

## Usage
```commandline
from testpypibkonon.m_mod_bkonon import name as n
from testpypibkonon.m_mod_bkonon import get_numpy_arr

>>> n("Name", "Surname")
Name Surname
>>> get_numpy_arr([1, 2, 3, 4, 5])
[1 2 3 4 5]
```